@@ -23,11 +23,18 @@
 void dblcen(double *a, int *na);
 
 void R_distance(double *x, int *nr, int *nc, double *d, int *diag, int *method);
+
+
+
 double R_euclidean(double *x, int nr, int nc, int i1, int i2);
 double R_maximum  (double *x, int nr, int nc, int i1, int i2);
 double R_manhattan(double *x, int nr, int nc, int i1, int i2);
 double R_canberra (double *x, int nr, int nc, int i1, int i2);
 double R_dist_binary(double *x, int nr, int nc, int i1, int i2);
+double R_pearson(double *x, int nr, int nc, int i1, int i2);
+double R_correlation(double *x, int nr, int nc, int i1, int i2);
+
+
 
 
 
@@ -39,14 +46,9 @@ int ioffst(int n,int i,int j);
 
 void hcass2( int *n, int *ia,  int *ib,int *iorder, int *iia, int *iib);
 
-void hcluster(double *x, int *nr, int *nc, int *diag, int *method, int *iopt ,int *ia , int *ib,int *iorder,double *crit,double *membr);
+int hcluster(double *x, int *nr, int *nc, int *diag, int *method, int *iopt ,int *ia , int *ib,int *iorder,double *crit,double *membr, int *result);
 
 
-void hclust(int *n,int *len, int *iopt ,int *ia , int *ib,int *iorder,double *crit,double *membr,double *diss);
 
+int hclust(int *n,int *len, int *iopt ,int *ia , int *ib,int *iorder,double *crit,double *membr,double *diss, int *result);
 
-void
-F77_SUB(kmns)(double *a, int *m, int *n, double *c, int *k,
-	      int *ic1, int *ic2, int *nc, double * an1, double *an2,
-	      int *ncp, double *d, int *itran,
-	      int *live, int *iter, double *wss, int *ifault);
